classdef CrashReport < handle
  % CrashReport
  %   Class containing log information about the crash that occurred
  %
  % Methods:
  %   getDescription - Get the description
  %   setDescription - Set the description
  %   getReport - Get the complete report
  %   save - Save report to disk
  %

  properties(Access=protected)
    mPtr = uint64(0);
  end

  methods(Access=public)
    function obj = CrashReport(varargin)
      % CrashReport
      %   Construct new crash_report class
      %
      % ----------
      %
      %   Generate crash report on a camera
      %
      % Inputs:
      %   1 - string - Camera to generate the crash report on
      %   2 - string - Description of what happened
      %

      if nargin == 1 && isa(varargin{1}, 'uint64')
        obj.mPtr = varargin{1};
      elseif nargin == 2 && (isStringScalar(varargin{1}) || ischar(varargin{1})) && (isStringScalar(varargin{2}) || ischar(varargin{2}))
        obj.mPtr = tof.mex('tof_crash_report_new', varargin{1}, varargin{2});
      elseif nargin == 1 && (isStringScalar(varargin{1}) || ischar(varargin{1})) && (isStringScalar(varargin{2}) || ischar(varargin{2}))
        obj.mPtr = tof.mex('tof_crash_report_new', varargin{1}, );
      else
        error("Can't construct empty object");
      end
    end


    function delete(obj)
      if obj.mPtr ~= 0
        tof.mex('tof_crash_report_delete', obj.mPtr);
        obj.mPtr = 0;
      end
    end

    function ptr = get_object_ptr(obj)
      ptr = obj.mPtr;
    end

    function ret_val = getDescription(obj)
      % getDescription
      %   Get the description
      %
      % Output:
      %   ret_val - string - Description
      %

      ret_val = tof.mex('tof_crash_report_get_description', obj.mPtr);
    end

    function setDescription(obj, description)
      % setDescription
      %   Set the description
      %
      % Inputs:
      %   description - string - Description
      %

      tof.mex('tof_crash_report_set_description', obj.mPtr, description);
    end

    function ret_val = getReport(obj)
      % getReport
      %   Get the complete report
      %
      % Output:
      %   ret_val - string - String of the entire report
      %

      ret_val = tof.mex('tof_crash_report_get_report', obj.mPtr);
    end

    function save(obj, file_name)
      % save
      %   Save report to disk
      %
      % Inputs:
      %   file_name - string - File to save the report to
      %

      tof.mex('tof_crash_report_save', obj.mPtr, file_name);
    end

  end
end
