#!/usr/bin/env python3
"""
Created on Mon Aug 24 13:55:47 2020

@author: refael

This is an example of streaming depth data from a KeaC camera which is running
mixed pixel on the camera its self. 
"""

import matplotlib.pyplot as plt
import chronoptics.tof as tof
import numpy as np


def handle_close(evt):
    cam.disconnect()
    return


serial = "2020004"  # camera to connect to
stream = tof.DepthStreamType.RADIAL  # Stream radial frames

cam = tof.GigeInterface()
cam.connect(cam.find(serial))

if not cam.depthStreamCapable(stream):
    raise RuntimeError(
        "Connected ToF Camera does not support on board depth calculation"
    )

config = cam.downloadConfiguration()
config.reset()
config.addFrame()

config.setModulationFrequency(0, 40.0)
config.setModulationFrequency(1, 80.0)

# Update the processing configuration
proc_config = tof.ProcessingConfig()
proc_config.setTemporalEnabled(True)
proc_config.setTemporalNframes(25)
proc_config.setPhaseUnwrappingEnabled(True)
proc_config.setMixedPixelEnabled(True)
proc_config.setMixedPixelLutFile("/home/root/luts/EmbeddedLUT_4080.bin")

config.setProcessing(proc_config)

cam.uploadConfiguration(config)

if not cam.testStreamPacketSize():
    raise RuntimeError("Looks like network is too slow to run camera!")

# Display the radial and intensity
cam.startDepthStream(stream)

fig = plt.figure()
fig.canvas.mpl_connect("close_event", handle_close)

roi = config.getRoi(0)

nrows = roi.getImgRows()
ncols = roi.getImgCols()

plt.subplot(111)
rimg = plt.imshow(
    np.zeros((nrows, ncols), dtype=np.uint16),
    cmap="jet",
    vmin=0,
    vmax=2**16,
    interpolation="none",
)
plt.title("Radial")

while cam.isConnected():
    while cam.hasDepthData():
        # This stops the display causing latency.
        frame = cam.getDepthData()
        if frame.frameType() == tof.FrameType.RADIAL:
            # Update radial frames
            rimg.set_data(np.array(frame))
            plt.draw()

        del frame

    plt.show(block=False)
    # This makes sure the event loop is updated
    plt.pause(0.1)

cam.disconnect()
